package com.xylink.config;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.model.AppToken;
import com.xylink.util.*;
import org.apache.commons.lang3.StringUtils;

import java.io.*;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * Created by wenya on 17/9/11.
 */
public class SDKConfigMgr{

    private static final String CONFIG_FILE = "/com/xylink/config/config.json";

    private static String DEFAULT_SERVER_HOST = "https://sdk.xylink.com";

    private static SDKConfig sdkConfig;

    private static boolean has_inited = false;

    private static final ObjectMapper objectMapper = new ObjectMapper();

    static {
        sdkConfig = loadConfigs();
        if(sdkConfig == null) {
            sdkConfig = new SDKConfig();
            sdkConfig.setServerHost(DEFAULT_SERVER_HOST);
        }
    }


    public static void initSDKConfig(String apiHost,String clientId,String clientSecret,String enterpriseId){
        if(has_inited){
            throw new RuntimeException("xylink sdk has inited!");
        }
        has_inited = true;
        sdkConfig.setServerHost(apiHost);
        sdkConfig.setXyClientid(clientId);
        sdkConfig.setXyClientSecret(clientSecret);
        sdkConfig.setEnterpriseId(enterpriseId);
        sdkConfig.setEnableNewSign(true);
        sdkConfig.setSignType(SignUtil.SignType.MD5);
        initAccesstoken(sdkConfig);
    }

    public static boolean enableNewSign(){
        return sdkConfig.isEnableNewSign();
    }

    public static String getServerHost() {
        return sdkConfig.getServerHost();
    }

    public static String getXyClientid() {
        return sdkConfig.getXyClientid();
    }

    public static String getAccessToken() {
        return sdkConfig.getAccessToken();
    }

    public static String getXySignSecret() {
        return sdkConfig.getXySignSecret();
    }

    public static void setServerHost(String host) {
        if(host == null || host.trim().isEmpty()) {
            throw new IllegalArgumentException("host cannot be empty.");
        }
        if(!DEFAULT_SERVER_HOST.equals(host.toLowerCase().trim())) {
            try {
                SslUtils.ignoreSsl();
            } catch (Exception e) {
                throw new IllegalArgumentException("Failed to ignore ssl cert.", e);
            }
        }
        sdkConfig.setServerHost(host);
    }

    public static void setSignType(SignUtil.SignType signType) {
        sdkConfig.setSignType(signType);
    }

    public static SignUtil.SignType getSignType() {
        return sdkConfig.getSignType();
    }

    private static SDKConfig loadConfigs() {
        try {
            InputStream inputStream = SDKConfigMgr.class.getResourceAsStream(CONFIG_FILE);
            SDKConfig sdkConfig = objectMapper.readValue(inputStream, SDKConfig.class);
            return sdkConfig;
        } catch (IOException e) {
            return new SDKConfig();
        }
    }

    private static void initAccesstoken(SDKConfig sdkConfig){
        try{
            if (null!=sdkConfig &&
                    StringUtils.isNotBlank(sdkConfig.getXyClientid()) &&
                    StringUtils.isNotBlank(sdkConfig.getXyClientSecret()) &&
                    StringUtils.isNotBlank(sdkConfig.getEnterpriseId())){
                AppToken appToken = new AppToken();
                appToken.setClient_id(sdkConfig.getXyClientid());
                appToken.setClient_secret(sdkConfig.getXyClientSecret());
                appToken.setEnterpriseId(sdkConfig.getEnterpriseId());
                String jsonEntity = new ObjectMapper().writeValueAsString(appToken);
                Result result = HttpUtil.getResponse(sdkConfig.getServerHost()+"/admin/login/oauth/app_token","POST",jsonEntity, Map.class);
                System.out.println(appToken.getClient_id() + " oauth appToken "+result);
                initOrFreshSdkConfig(result);
                runSchedulerJob();
                System.out.println("initAccesstoken scheduler refesh client init delay "+(sdkConfig.getAccessTokenExpireIn()-1800));
            }
        }catch(Exception e){
            System.out.println("initAccesstoken error"+e.getMessage());
            throw new RuntimeException(e);
        }
    }

    private static void runSchedulerJob(){
        SchedulerUtil.schedule(new Runnable() {
            @Override
            public void run() {
                refreshToken();
            }
        }, sdkConfig.getAccessTokenExpireIn()-1800, TimeUnit.SECONDS);
    }

    private static void refreshToken(){
        if (null!=sdkConfig && StringUtils.isNotBlank(sdkConfig.getRefreshToken())){
            AppToken appToken = new AppToken();
            appToken.setRefresh_token(sdkConfig.getRefreshToken());
            appToken.setClient_id(sdkConfig.getXyClientid());
            try{
                String jsonEntity = new ObjectMapper().writeValueAsString(appToken);
                Result result = HttpUtil.getResponse(sdkConfig.getServerHost()+"/admin/login/refresh_token","POST",jsonEntity, Map.class);
                System.out.println(appToken.getRefresh_token() + " refreshToken "+result);
                if (result.isSuccess()){
                    initOrFreshSdkConfig(result);
                    runSchedulerJob();
                    System.out.println("refreshToken scheduler refesh client init delay "+(sdkConfig.getAccessTokenExpireIn()-1800));
                }else if (!result.isSuccess() && 10002014==((RestMessage)result.getData()).getErrorCode()){
                    initAccesstoken(sdkConfig);
                }
            }catch(Exception e){
                System.out.println("refreshToken error "+e.getMessage());
                throw new RuntimeException(e);
            }
        }
    }

    private static void initOrFreshSdkConfig(Result result){
        if (result.isSuccess()){
            Map appTokenMap = (Map)result.getData();
            if (appTokenMap.get("message").equals("success")){
                sdkConfig.setAccessToken((String) ((Map)appTokenMap.get("data")).get("access_token"));
                sdkConfig.setRefreshToken((String) ((Map)appTokenMap.get("data")).get("refresh_token"));
                sdkConfig.setXySignSecret((String) ((Map)appTokenMap.get("data")).get("signSecret"));
                sdkConfig.setAccessTokenExpireIn((Integer) ((Map)appTokenMap.get("data")).get("expires_in"));
                System.out.println("initOrFreshSdkConfig success "+sdkConfig);
            }
        }
    }
}
