package com.xylink.sdk.dating;

import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.Pager;
import com.xylink.model.ReminderMeeting;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;
import org.apache.commons.lang3.StringUtils;

import java.io.IOException;
import java.util.Map;

/**
 * Created by maolizhi on 12/16/2016.
 */
public class ScheduleMeetingApi {
    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrl = "/api/rest/external/v1/meetingreminders";

    /**
     * schedule a meeting,if success,the date type of Result is "String",the date value is meeting id;if not ,
     * the date type of Result is "RestMessage"
     * @param enterpriseId
     * @param token
     * @param reminderMeeting
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result remindMeeting(String enterpriseId, String token, ReminderMeeting reminderMeeting, int maxParticipantCount)
            throws IOException {
        String surl = getPrefixUrl()  + "?enterpriseId=" + enterpriseId + "&maxParticipant=" + maxParticipantCount;
        String jsonEntity = new ObjectMapper().writeValueAsString(reminderMeeting);
        String signature = signatureSample.computeSignature(jsonEntity,"POST",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"POST", jsonEntity,Map.class);

    }

    /**
     * schedule a meeting,if success,the date type of Result is "String",the date value is meeting id;if not ,
     * the date type of Result is "RestMessage"
     * @param enterpriseId
     * @param token
     * @param reminderMeeting
     * @return
     * @throws IOException
     */
    public Result remindMeeting(String enterpriseId, String token, ReminderMeeting reminderMeeting)
            throws IOException {
        String surl = getPrefixUrl()  + "?enterpriseId=" + enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(reminderMeeting);
        String signature = signatureSample.computeSignature(jsonEntity,"POST",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"POST", jsonEntity, Map.class);

    }

    /**
     * update meeting
     * @param enterpriseId
     * @param token
     * @param meetingId
     * @param reminderMeeting
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result updateMeeting(String enterpriseId, String token,String meetingId, ReminderMeeting reminderMeeting, int maxParticipantCount)
            throws IOException {
        String surl = getPrefixUrl() + "/" + meetingId + "?enterpriseId=" + enterpriseId + "&maxParticipant=" + maxParticipantCount;
        String jsonEntity = new ObjectMapper().writeValueAsString(reminderMeeting);
        String signature = signatureSample.computeSignature(jsonEntity,"PUT",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"PUT", jsonEntity,null);

    }

    /**
     * update meeting
     * @param enterpriseId
     * @param token
     * @param meetingId
     * @param reminderMeeting
     * @return
     * @throws IOException
     */
    public Result updateMeeting(String enterpriseId, String token,String meetingId, ReminderMeeting reminderMeeting)
            throws IOException {
        String surl = getPrefixUrl() + "/" + meetingId + "?enterpriseId=" + enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(reminderMeeting);
        String signature = signatureSample.computeSignature(jsonEntity,"PUT",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"PUT", jsonEntity,null);

    }

    public Result deleteMeeting(String enterpriseId, String token,String meetingId) throws IOException{
        String surl = getPrefixUrl() + "/" + meetingId + "?enterpriseId=" + enterpriseId;
        String signature = signatureSample.computeSignature("","DELETE",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"DELETE", null,null);


    }

    /**
     * 按照预约会议ID获取预约会议详情
     * @param enterpriseId
     * @param token
     * @param meetingId:预约会议id
     * @return
     * @throws IOException
     */
    public Result<ReminderMeeting> getMeeting(String enterpriseId, String token,String meetingId) throws IOException{
        String surl = getPrefixUrl() + "/" + meetingId + "?enterpriseId=" + enterpriseId;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,ReminderMeeting.class);
    }
    /**
     * get all meetings who's end time is bigger than  the parmater "endTime",
     * if success,the date type of Result is "ReminderMeeting[]",the date value is meeting id;if not ,
     * the date type of Result is "RestMessage"
     * @param enterpriseId
     * @param token
     * @param endTime
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result<ReminderMeeting[]> getAllMeeting(String enterpriseId, String token, long endTime)
            throws IOException {
        String surl = getPrefixUrl()  + "?enterpriseId=" + enterpriseId + "&endTime="+endTime;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null,ReminderMeeting[].class);
    }

    public Result<Pager<ReminderMeeting>> getMeeting(String enterpriseId, String token, int page, int size, long endTime) throws IOException {

        String surl = getPrefixUrl() + "/page?enterpriseId=" + enterpriseId + "&pageIndex=" + page + "&pageSize=" + size +"&endTime=" + endTime;
        String signature = signatureSample.computeSignature("", "GET", token, surl);
        surl += "&signature=" + signature;
        Result<String> resp = HttpUtil.getResponse(surl, "GET", null, String.class);

        Result<Pager<ReminderMeeting>> result = new Result<Pager<ReminderMeeting>>();
        result.setSuccess(resp.isSuccess());
        result.setErrorStatus(resp.getErrorStatus());
        result.setErrorMsg(resp.getErrorMsg());

        if (resp.isSuccess() && StringUtils.isNotBlank(resp.getData())) {
            ObjectMapper objectMapper = new ObjectMapper();
            Pager<ReminderMeeting> pager = objectMapper.readValue(resp.getData(), new TypeReference<Pager<ReminderMeeting>>() {});
            result.setData(pager);
        }

        return result;
    }

    public Result<Pager> getMeetingByConfrenceNumber(String enterpriseId, String token, Integer pageIndex, Integer pageSize, String meetingRoomNumber) throws IOException {
        String surl = getPrefixUrl() + "/conference?enterpriseId=" + enterpriseId + "&pageIndex=" + pageIndex + "&pageSize=" + pageSize +"&meetingRoomNumber=" + meetingRoomNumber;
        String signature = signatureSample.computeSignature("", "GET", token, surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl, "GET", null, Pager.class);
    }

    private ReminderMeeting convert2ReminderMeeting(Map<String, Object> map) {
        ReminderMeeting reminderMeeting = new ReminderMeeting();
        reminderMeeting.setId((String) map.get("id"));
        return reminderMeeting;
    }

    private String getPrefixUrl() {
        return SDKConfigMgr.getServerHost() + prefixUrl;
    }
}
