package com.xylink.sdk.liveVideo.v3;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.xylink.config.SDKConfigMgr;
import com.xylink.model.*;
import com.xylink.util.HttpUtil;
import com.xylink.util.Result;
import com.xylink.util.SignatureSample;
import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * created by maolizhi at 03/14/2017
 */
public class LiveVideoApi {
    private static SignatureSample signatureSample = new SignatureSample();
    private static final String prefixUrl = "/api/rest/external/v1/liveVideo3/enterprise/";
    /**
     * create LiveVideo,if Result Object's success is true,
     * the "data" type of Result is LV;if not, the "data" type of Result is RestMessage
     * @param enterpriseId
     * @param token
     * @param confNo
     * @param liveVideo
     * @return
     * @throws IOException
     */
    @Deprecated
    public Result<LV> newLiveVideo(String enterpriseId,String token,String confNo,LiveVideo liveVideo) throws IOException{
        String surl = getPrefixUrl() + enterpriseId + "/conf/" + confNo + "/live?enterpriseId="+enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(liveVideo);
        String signature = signatureSample.computeSignature(jsonEntity,"POST",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"POST", jsonEntity, LV.class);
    }
    /**
     * shcedule a live for conference
     * @param enterpriseId
     * @param token
     * @param confNo
     * @param confPwd
     * @param liveVideo
     * @return
     * @throws IOException
     */
    public Result<LiveVideoForConference> scheduleLive(String enterpriseId, String token, String confNo, String confPwd,boolean needExtras, LiveVideo liveVideo) throws IOException{
        String surl = getPrefixUrl() + enterpriseId + "/conf/" + confNo + "/live?enterpriseId=" + enterpriseId + "&confPwd=" + confPwd + "&needExtras=" + needExtras;
        String jsonEntity = new ObjectMapper().writeValueAsString(liveVideo);
        String signature = signatureSample.computeSignature(jsonEntity,"POST",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"POST", jsonEntity, LiveVideoForConference.class);
    }

    /**
     * update live
     * @param enterpriseId
     * @param token
     * @param confNo
     * @param confPwd , it is can be empty
     * @param liveId
     * @param liveVideo
     * @return
     * @throws IOException
     */
    public Result updateLive(String enterpriseId,String token,String confNo,String confPwd,String liveId,LiveVideo liveVideo,boolean onlyThirdPartyPushUrl)
            throws IOException{
        String surl = getPrefixUrl() + enterpriseId + "/conf/" + confNo + "/live/" +liveId
                + "?enterpriseId="+enterpriseId + "&confPwd=" + confPwd+"&onlyThirdPartyPushUrl="+onlyThirdPartyPushUrl;
        String jsonEntity = new ObjectMapper().writeValueAsString(liveVideo);
        String signature = signatureSample.computeSignature(jsonEntity,"PUT",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"PUT", jsonEntity, null);
    }

    /**
     * delete live
     * @param enterpriseId
     * @param token
     * @param confNo
     * @param confPwd
     * @param liveId
     * @return
     * @throws IOException
     */
    public Result deleteLive(String enterpriseId,String token,String confNo,String confPwd,String liveId)throws IOException{
        String surl = getPrefixUrl()  + enterpriseId + "/conf/" + confNo + "/live/" +liveId
                + "?enterpriseId="+enterpriseId + "&confPwd=" + confPwd;
        String signature = signatureSample.computeSignature("","DELETE",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"DELETE", null, null);
    }

    /**
     * get the live
     * @param enterpriseId
     * @param token
     * @param confNo
     * @param confPwd
     * @param liveId
     * @return
     * @throws IOException
     */
    public Result getLive(String enterpriseId,String token,String confNo,String confPwd,String liveId,boolean needExtras) throws IOException{
        String surl = getPrefixUrl() + enterpriseId + "/conf/" + confNo + "/live/" +liveId
                + "?enterpriseId=" + enterpriseId + "&confPwd=" + confPwd + "&needExtras=" + needExtras;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, String.class);
    }

    /**
     * get video list for the live
     * @param enterpriseId
     * @param token
     * @param confNo
     * @param confPwd
     * @param liveId
     * @return
     * @throws IOException
     */
    public Result<Video[]> getLiveVideoList(String enterpriseId, String token, String confNo, String confPwd, String liveId) throws IOException{
        String surl = getPrefixUrl() + enterpriseId + "/conf/" + confNo + "/live/" +liveId + "/videoswithduration"
                + "?enterpriseId="+enterpriseId + "&confPwd=" + confPwd;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        System.out.println(surl);
        return HttpUtil.getResponse(surl,"GET", null, Video[].class);
    }

    /**
     * 按直播id批量查询回放列表.md
     * @param enterpriseId
     * @param token
     * @param confLiveVideoRequests
     * @return
     * @throws IOException
     */
    public Result<ConferenceLiveVideos> getLiveVideoListByIds(String enterpriseId, String token,List<ConfLiveVideoRequest> confLiveVideoRequests) throws IOException{
        String surl = getPrefixUrl() +"liveVideoList" + "?enterpriseId="+enterpriseId;
        String jsonEntity = new ObjectMapper().writeValueAsString(confLiveVideoRequests);
        String signature = signatureSample.computeSignature(jsonEntity,"PUT",token,surl);
        surl += "&signature=" + signature;
        System.out.println(surl);
        return HttpUtil.getResponse(surl,"PUT", jsonEntity, ConferenceLiveVideos[].class);
    }

    /**
     * start/end the live
     * @param enterpriseId
     * @param token
     * @param confNo
     * @param confPwd
     * @param liveId
     * @param status
     * @return
     * @throws IOException
     */
    public Result controlLive(String enterpriseId, String token, String confNo, String confPwd, String liveId,Status status)throws IOException{
        String surl = getPrefixUrl() + enterpriseId + "/conf/" + confNo + "/live/" + liveId + "/status"
                + "?enterpriseId="+enterpriseId + "&confPwd=" + confPwd;
        String jsonEntity = new ObjectMapper().writeValueAsString(status);
        String signature = signatureSample.computeSignature(jsonEntity,"PUT",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"PUT", jsonEntity, null);
    }

    /**
     * 根据直播状态查询企业下直播列表
     * @param enterpriseId
     * @param token
     * @param liveStatus
     * @param pageIndex
     * @param pageSize
     * @return
     * @throws IOException
     */
    public Result getEnterpriseLivesPageByStatus(String enterpriseId, String token, int liveStatus, String type, int pageIndex, int pageSize, boolean needExtras) throws IOException {
        String surl = getPrefixUrl() + "live/page?enterpriseId=" + enterpriseId + "&liveStatus=" + liveStatus + "&type=" + type + "&pageIndex=" + pageIndex + "&pageSize=" + "&needExtras=" + needExtras;
        String signature = signatureSample.computeSignature("","GET",token,surl);
        surl += "&signature=" + signature;
        return HttpUtil.getResponse(surl,"GET", null, Map.class);
    }

    private String getPrefixUrl() {
        return SDKConfigMgr.getServerHost() + prefixUrl;
    }

}
