package com.xylink.util;

import com.xylink.config.SDKConfigMgr;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import java.net.URLEncoder;
import java.security.SignatureException;
import java.util.*;

/**
 * Created by wenya on 16/9/10.
 */
public class SignatureSample {

    private static final String SIGNATURE = "signature";
    private static final String WEBSOCKET_API = "websocket/message";

    protected String computeStringToSign(String requestPath, Map<String, String> reqParams, String reqJsonEntity, String reqMethod) throws Exception{
        //1. request method
        StringBuffer strToSign = new StringBuffer(reqMethod);
        strToSign.append("\n");
        //2. request path
        strToSign.append(getPathToVerify(requestPath));
        strToSign.append("\n");
        //3. sorted request param and value
        List<String> params = new ArrayList<String>(reqParams.keySet());
        Collections.sort(params);
        for(String param : params) {
            if(SIGNATURE.equals(param.trim()))
                continue;
            strToSign.append(param);
            strToSign.append("=");
            strToSign.append(reqParams.get(param));
            strToSign.append("&");
        }
        strToSign.deleteCharAt(strToSign.length()-1);
        strToSign.append("\n");
        //4. request entity
//        byte[] reqEntity = reqJsonEntity.getBytes("utf-8");
        byte[] reqEntity = new byte[0];
        if (StringUtils.isNotBlank(reqJsonEntity)){
            reqEntity = reqJsonEntity.getBytes("utf-8");
        }
        //printArray(reqEntity);
        if(reqEntity.length == 0) {
            byte[] entity = DigestUtils.sha256("");
            strToSign.append(Base64.encodeBase64String(entity));
        } else {
            byte[] data = null;
            if(reqEntity.length <= 100) {
                data = reqEntity;
            } else {
                data = Arrays.copyOf(reqEntity, 100);
            }
            byte[] entity = DigestUtils.sha256(data);
           // printArray(entity);
            strToSign.append(Base64.encodeBase64String(entity));
        }

        String ret = strToSign.toString();
        System.out.println(ret);
        System.out.println("------------------");
        return ret;
    }

    private String getPathToVerify(String url) {
        if (url.startsWith("wss://")||url.startsWith("ws://")){
            return WEBSOCKET_API;
        }
        return url.replaceAll("(https|http)://.+/api/rest/external/v[0-9]{1,2}/","");
    }

    private void printArray(byte[] data) {
        StringBuffer sb = new StringBuffer();
        for(byte d : data) {
            sb.append(d);
            sb.append(",");
        }
        System.out.println(sb.toString());
    }

    private String calculateHMAC(String data, String key) throws SignatureException {
        try {
            SecretKeySpec e = new SecretKeySpec(key.getBytes("UTF8"), "HmacSHA256");
            Mac mac = Mac.getInstance("HmacSHA256");
            mac.init(e);
            byte[] rawHmac = mac.doFinal(data.getBytes("UTF8"));
            String result = Base64.encodeBase64String(rawHmac);
            return result;
        } catch (Exception var6) {
            throw new SignatureException("Failed to generate HMAC : " + var6.getMessage());
        }
    }

    public String computeSignature(String jsonEntity, String method, String token, String reqPath) {
        if (SDKConfigMgr.enableNewSign()){
            return SIGNATURE;
        }
        try {
        Map<String, String> reqParams = new HashMap<String, String>();
        int idx = reqPath.indexOf("?");
        String[] params = reqPath.substring(idx + 1).split("&");
        for(String param : params) {
            String[] pair = param.split("=");
            if (pair.length == 1){
                reqParams.put(pair[0], "");
            }else {
                reqParams.put(pair[0], pair[1]);
            }
        }
        reqPath = reqPath.substring(0, idx);
        String strToSign = computeStringToSign(reqPath, reqParams, jsonEntity, method);
        String mySignature = calculateHMAC(strToSign, token);
        mySignature = mySignature.replace(" ", "+");
        return URLEncoder.encode(mySignature, "utf-8");
    } catch (Exception e) {
        return null;
    }
    }
}
